@@ -59,6 +59,12 @@ if [ ! -e "${SIGNTOOL}" ]; then
 		SIGNTOOL="${PROGRAMFILES_X86}\\Windows Kits\\8.1\\Bin\\x64\\signtool.exe"
 	fi
 fi
+if [ ! -e "${SIGNTOOL}" ]; then
+	SIGNTOOL=`find /c/Program\ Files* -wholename "*/x64/signtool.exe"`
+fi
+if [ -e "${SIGNTOOL}" ]; then
+	cp "$SIGNTOOL" ./
+fi
 
 ################################################################################
 # Get version information, generate filenames
@@ -348,6 +354,9 @@ if [ "${BUNDLE_PUTTY}" == "1" ]; then
 		fi
 	fi
 	cp -fn "${TORTOISESVN}/bin/TortoisePlink.exe" "${DIST}/Plink.exe"
+	for dll in vcruntime140.dll msvcp140.dll vcruntime140_1.dll; do
+		cp "/c/Windows/System32/$dll" "${DIST}/"
+	done
 	#are we meant to include those DLLs?
 	#rsync -rplogt "${TORTOISESVN}/bin/"*dll "${DIST}/"
 fi
@@ -376,11 +385,11 @@ fi
 if [ "${DO_VERPATCH}" == "1" ]; then
 	for exe in `ls dist/*exe | grep -v Plink.exe`; do
 		tool_name=`echo $exe | sed 's+dist/++g;s+Xpra_++g;s+Xpra-++g;s+_+ +g;s+-+ +g;s+\.exe++g'`
-		verpatch $exe				//s desc "Xpra $tool_name"		//va "${ZERO_PADDED_VERSION}" //s company "xpra.org" //s copyright "(c) xpra.org 2019" //s product "xpra" //pv "${ZERO_PADDED_VERSION}"
+		verpatch $exe				//s desc "Xpra $tool_name"		//va "${ZERO_PADDED_VERSION}" //s company "xpra.org" //s copyright "(c) xpra.org 2020" //s product "xpra" //pv "${ZERO_PADDED_VERSION}"
 	done
-	verpatch dist/Xpra_cmd.exe 		//s desc "Xpra command line"	//va "${ZERO_PADDED_VERSION}" //s company "xpra.org" //s copyright "(c) xpra.org 2019" //s product "xpra" //pv "${ZERO_PADDED_VERSION}"
-	verpatch dist/Xpra-Proxy.exe	//s desc "Xpra Proxy Server"	//va "${ZERO_PADDED_VERSION}" //s company "xpra.org" //s copyright "(c) xpra.org 2019" //s product "xpra" //pv "${ZERO_PADDED_VERSION}"
-	verpatch dist/Xpra.exe 			//s desc "Xpra" 				//va "${ZERO_PADDED_VERSION}" //s company "xpra.org" //s copyright "(c) xpra.org 2019" //s product "xpra" //pv "${ZERO_PADDED_VERSION}"
+	verpatch dist/Xpra_cmd.exe 		//s desc "Xpra command line"	//va "${ZERO_PADDED_VERSION}" //s company "xpra.org" //s copyright "(c) xpra.org 2020" //s product "xpra" //pv "${ZERO_PADDED_VERSION}"
+	verpatch dist/Xpra-Proxy.exe	//s desc "Xpra Proxy Server"	//va "${ZERO_PADDED_VERSION}" //s company "xpra.org" //s copyright "(c) xpra.org 2020" //s product "xpra" //pv "${ZERO_PADDED_VERSION}"
+	verpatch dist/Xpra.exe 			//s desc "Xpra" 				//va "${ZERO_PADDED_VERSION}" //s company "xpra.org" //s copyright "(c) xpra.org 2020" //s product "xpra" //pv "${ZERO_PADDED_VERSION}"
 fi
 
 ################################################################################
@@ -432,7 +441,7 @@ if [ "${DO_INSTALLER}" == "1" ]; then
 	if [ "${DO_SIGN}" == "1" ]; then
 		SIGNTOOL_LOG="win32/signtool.log"
 		echo "* Signing EXE"
-		cmd.exe //c "${SIGNTOOL}" sign //v //f "${KEY_FILE}" //t "http://timestamp.comodoca.com/authenticode" "${INSTALLER_FILENAME}" > ${SIGNTOOL_LOG}
+		cmd.exe //c signtool.exe sign //v //f "${KEY_FILE}" //t "http://timestamp.comodoca.com/authenticode" "${INSTALLER_FILENAME}" > ${SIGNTOOL_LOG}
 		if [ "$?" != 0 ]; then
 			echo "signtool command failed, see ${SIGNTOOL_LOG}:"
 			cat ${SIGNTOOL_LOG}
@@ -467,7 +476,7 @@ if [ "${DO_MSI}" == "1" ]; then
 	if [ "${DO_SIGN}" == "1" ]; then
 		SIGNTOOL_LOG="win32/signtool.log"
 		echo "* Signing MSI"
-		cmd.exe //c "${SIGNTOOL}" sign //v //f "${KEY_FILE}" //t "http://timestamp.comodoca.com/authenticode" "${MSI_FILENAME}" > ${SIGNTOOL_LOG}
+		cmd.exe //c signtool.exe sign //v //f "${KEY_FILE}" //t "http://timestamp.comodoca.com/authenticode" "${MSI_FILENAME}" > ${SIGNTOOL_LOG}
 		if [ "$?" != 0 ]; then
 			echo "signtool command failed, see ${SIGNTOOL_LOG}:"
 			cat ${SIGNTOOL_LOG}
