@@ -76,10 +76,10 @@ PAINT_FLUSH = envbool("XPRA_PAINT_FLUSH", True)
 JPEG_YUV = envbool("XPRA_JPEG_YUV", True)
 WEBP_YUV = envbool("XPRA_WEBP_YUV", True)
 FORCE_CLONE = envbool("XPRA_OPENGL_FORCE_CLONE", False)
-DRAW_REFRESH = envbool("XPRA_OPENGL_DRAW_REFRESH", PYTHON3)
+DRAW_REFRESH = envbool("XPRA_OPENGL_DRAW_REFRESH", True)
 FBO_RESIZE = envbool("XPRA_OPENGL_FBO_RESIZE", True)
 FBO_RESIZE_DELAY = envint("XPRA_OPENGL_FBO_RESIZE_DELAY", 50)
-CONTEXT_REINIT = envbool("XPRA_OPENGL_CONTEXT_REINIT", OSX)
+CONTEXT_REINIT = envbool("XPRA_OPENGL_CONTEXT_REINIT", False)
 
 CURSOR_IDLE_TIMEOUT = envint("XPRA_CURSOR_IDLE_TIMEOUT", 6)
 TEXTURE_CURSOR = envbool("XPRA_OPENGL_TEXTURE_CURSOR", True)
@@ -255,6 +255,10 @@ class GLWindowBackingBase(WindowBackingBase):
         self.bit_depth = self.get_bit_depth(pixel_depth)
         self.init_formats()
         self.draw_needs_refresh = DRAW_REFRESH
+        #the correct check would be this:
+        #self.repaint_all = self.is_double_buffered() or bw!=ww or bh!=wh
+        #but we're meant to be using double-buffered everywhere, so don't bother:
+        self.repaint_all = True
         self._backing.show()
 
     def init_gl_config(self, window_alpha):
@@ -347,6 +351,7 @@ class GLWindowBackingBase(WindowBackingBase):
         #and then doing the gl_init() call but without initializing the offscreen fbo.
         sx, sy, dx, dy, w, h = self.gravity_copy_coords(oldw, oldh, bw, bh)
         with context:
+            context.update_geometry()
             #invert Y coordinates for OpenGL:
             sy = (oldh-h)-sy
             dy = (bh-h)-dy
@@ -630,7 +635,8 @@ class GLWindowBackingBase(WindowBackingBase):
             glBindTexture(target, 0)
             glDisable(target)
             fire_paint_callbacks(callbacks, True)
-            self.present_fbo(0, 0, bw, bh, flush)
+            if not self.draw_needs_refresh:
+                self.present_fbo(0, 0, bw, bh, flush)
 
     def copy_fbo(self, w, h, sx=0, sy=0, dx=0, dy=0):
         #copy from offscreen to tmp:
@@ -1068,7 +1074,8 @@ class GLWindowBackingBase(WindowBackingBase):
                 glDisable(target)
                 self.paint_box(options.strget("encoding"), options.intget("delta", -1)>=0, x, y, width, height)
                 # Present update to screen
-                self.present_fbo(x, y, width, height, options.intget("flush", 0))
+                if not self.draw_needs_refresh:
+                    self.present_fbo(x, y, width, height, options.intget("flush", 0))
                 # present_fbo has reset state already
             fire_paint_callbacks(callbacks)
             return
@@ -1122,7 +1129,8 @@ class GLWindowBackingBase(WindowBackingBase):
                 self.paint_box(encoding, False, x, y, width, height)
                 fire_paint_callbacks(callbacks, True)
                 # Present it on screen
-                self.present_fbo(x, y, width, height, flush)
+                if not self.draw_needs_refresh:
+                    self.present_fbo(x, y, width, height, flush)
             img.free()
             return
         except GLError as e:
