@@ -551,7 +551,7 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
             #this generates a configure event which ensures the server has the correct window position
             wfs = self._client.get_window_frame_sizes()
             if wfs and decorated and not was_decorated:
-                geomlog("set_decorated(%s) re-adjusting window location using %s", wfs)
+                geomlog("set_decorated(%s) re-adjusting window location using %s", decorated, wfs)
                 normal = wfs.get("normal")
                 fixed = wfs.get("fixed")
                 if normal and fixed:
@@ -1761,7 +1761,10 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
             #we may have cleared the backing, so we must re-create one:
             self._set_backing_size(w, h)
         if not self._override_redirect:
-            self.idle_add(self._focus_change, "initial")
+            htf = self.has_toplevel_focus()
+            focuslog("mapped: has-toplevel-focus=%s", htf)
+            if htf:
+                self._client.update_focus(self._id, htf)
 
     def get_window_frame_size(self):
         frame = self._client.get_frame_extents(self)
