@@ -28,8 +28,8 @@ class KeyboardConfig(KeyboardConfigBase):
         keycode = KEYCODES.get(keyname, -1)
         if keycode==-1:
             keycode = KEYCODES.get(keyname.upper(), -1)
-        log("get_keycode%s=%s", (client_keycode, keyname, pressed, modifiers), keycode)
-        return keycode
+        log("get_keycode%s=%s, %s", (client_keycode, keyname, pressed, modifiers), keycode, group)
+        return keycode, group
 
 #we currently assume that all key events are sent using X11 names,
 #so we need to translate them to osx keys
