@@ -9,11 +9,11 @@ from ctypes import (
     WinError, FormatError,
     )
 from xpra.platform.win32.common import (
-    WNDCLASSEX, GetLastError, ERROR_ACCESS_DENIED, WNDPROC, LPCWSTR, LPWSTR,
+    WNDCLASSEX, GetLastError, WNDPROC, LPCWSTR, LPWSTR,
     DefWindowProcW,
     GetModuleHandleA, RegisterClassExW, UnregisterClassA,
     CreateWindowExW, DestroyWindow,
-    OpenClipboard, EmptyClipboard, CloseClipboard, GetClipboardData,
+    OpenClipboard, EmptyClipboard, CloseClipboard, GetClipboardData, GetClipboardOwner,
     GlobalLock, GlobalUnlock, GlobalAlloc, GlobalFree,
     WideCharToMultiByte, MultiByteToWideChar,
     AddClipboardFormatListener, RemoveClipboardFormatListener,
@@ -24,7 +24,7 @@ from xpra.clipboard.clipboard_core import (
     ClipboardProxyCore, log, _filter_targets,
     TEXT_TARGETS, MAX_CLIPBOARD_PACKET_SIZE,
     )
-from xpra.util import csv, repr_ellipsized
+from xpra.util import csv, repr_ellipsized, envbool
 from xpra.os_util import bytestostr, strtobytes
 from xpra.gtk_common.gobject_compat import import_glib
 
@@ -55,6 +55,9 @@ CLIPBOARD_EVENTS = {
     win32con.WM_VSCROLLCLIPBOARD    : "WM_VSCROLLCLIPBOARD",
     }
 
+CONVERT_LINE_ENDINGS = envbool("XPRA_CONVERT_LINE_ENDINGS", True)
+
+
 #initialize the window we will use
 #for communicating with the OS clipboard API:
 
@@ -147,28 +150,22 @@ class Win32ClipboardProxy(ClipboardProxyCore):
         self.send_clipboard_token_handler = send_clipboard_token_handler
         ClipboardProxyCore.__init__(self, selection)
 
-    def set_want_targets(self, want_targets):
-        self._want_targets = want_targets
-
     def with_clipboard_lock(self, success_callback, failure_callback, retries=5, delay=5):
         r = OpenClipboard(self.window)
-        log("OpenClipboard(%#x)=%s", self.window, r)
         if r:
+            log("OpenClipboard(%#x)=%s", self.window, r)
             try:
                 success_callback()
                 return
             finally:
                 CloseClipboard()
-        if GetLastError()!=ERROR_ACCESS_DENIED:
-            failure_callback("OpenClipboard: access denied")
-            return
-        log("clipboard lock: access denied")
+        log("OpenClipboard(%#x)=%s, owner=%#x", self.window, WinError(GetLastError()), GetClipboardOwner())
         if retries<=0:
             failure_callback("OpenClipboard: too many failed attemps, giving up")
             return
         #try again later:
         glib.timeout_add(delay, self.with_clipboard_lock,
-                         success_callback, failure_callback, retries-1, delay)
+                         success_callback, failure_callback, retries-1, delay+5)
 
     def clear(self):
         def clear_error(error_text=""):
@@ -189,9 +186,15 @@ class Win32ClipboardProxy(ClipboardProxyCore):
         self.send_clipboard_token_handler(self)
 
     def get_contents(self, target, got_contents):
+        log("get_contents%s", (target, got_contents))
         if target=="TARGETS":
             #we only support text at the moment:
-            got_contents("ATOM", 32, ["text/plain", "text/plain;charset=utf-8", "UTF8_STRING"])
+            got_contents("ATOM", 32, ["TEXT", "STRING", "text/plain", "text/plain;charset=utf-8", "UTF8_STRING"])
+            return
+        if target not in ("TEXT", "STRING", "text/plain", "text/plain;charset=utf-8", "UTF8_STRING"):
+            #we don't know how to handle this target,
+            #return an empty response:
+            got_contents(target, 8, b"")
             return
         def got_text(text):
             log("got_text(%s)", repr_ellipsized(bytestostr(text)))
@@ -200,7 +203,7 @@ class Win32ClipboardProxy(ClipboardProxyCore):
             log.error("Error: failed to get clipboard data")
             if error_text:
                 log.error(" %s", error_text)
-            got_contents("text/plain", 8, b"")
+            got_contents(target, 8, b"")
         self.get_clipboard_text(got_text, errback)
 
 
@@ -268,8 +271,12 @@ class Win32ClipboardProxy(ClipboardProxyCore):
                         s = buf.raw[:l-1]
                     else:
                         s = buf.raw[:l]
+                    if CONVERT_LINE_ENDINGS:
+                        v = s.decode("utf8").replace("\r\n", "\n").encode("utf8")
+                    else:
+                        v = strtobytes(s)
                     log("got %i bytes of data: %s", len(s), repr_ellipsized(str(s)))
-                    callback(strtobytes(s))
+                    callback(v)
                 else:
                     errback("failed to convert to UTF8: %s" % FormatError(get_last_error()))
             finally:
@@ -293,6 +300,8 @@ class Win32ClipboardProxy(ClipboardProxyCore):
     def do_set_clipboard_text(self, text):
         #convert to wide char
         #get the length in wide chars:
+        if CONVERT_LINE_ENDINGS:
+            text = text.decode("utf8").replace("\n", "\r\n").encode("utf8")
         wlen = MultiByteToWideChar(CP_UTF8, MB_ERR_INVALID_CHARS, text, len(text), None, 0)
         if not wlen:
             self.set_err("failed to prepare to convert to wide char")
@@ -325,7 +334,6 @@ class Win32ClipboardProxy(ClipboardProxyCore):
         #    self.set_err("failed to empty the clipboard")
         #self.with_clipboard_lock(EmptyClipboard, empty_error)
         def cleanup():
-            GlobalFree(buf)
             glib.idle_add(self.remove_block)
         ret = [False]
         def do_set_data():
