@@ -233,7 +233,7 @@ class XpraServer(gobject.GObject, X11ServerBase):
             return False
         #check for an existing window manager:
         from xpra.x11.gtk_x11.wm_check import wm_check
-        if not wm_check(self.wm_name, self.clobber):
+        if not wm_check(self.wm_name, self.clobber & 0x1):
             return False
         return True
 
@@ -829,7 +829,8 @@ class XpraServer(gobject.GObject, X11ServerBase):
         #x_root, y_root, direction, button, source_indication = event.data
         wid = self._window_to_id[window]
         #find clients that handle windows:
-        wsources = [ss for ss in self._server_sources.values() is isinstance(ss, WindowsMixin)]
+        from xpra.server.source.windows_mixin import WindowsMixin
+        wsources = [ss for ss in self._server_sources.values() if isinstance(ss, WindowsMixin)]
         if not wsources:
             return
         #prefer the "UI driver" if we find it:
@@ -864,7 +865,7 @@ class XpraServer(gobject.GObject, X11ServerBase):
             frame = nws.intlistget("frame", (0, 0, 0, 0))
             window.set_property("frame", frame)
         #boolean: but not a wm_state and renamed in the model... (iconic vs inconified!)
-        iconified = nws.boolget("iconified")
+        iconified = nws.boolget("iconified", None)
         if iconified is not None:
             if window.is_OR():
                 log("ignoring iconified=%s on OR window %s", iconified, window)
